@@ -1,6 +1,11 @@
 from pydantic import BaseModel
 from typing import List
-from deeploy.models import PredictionLog
+from deeploy.models import RequestLog, PredictionLog
+
+
+class RequestLogs(BaseModel):
+    data: List[RequestLog]
+    count: int
 
 
 class PredictionLogs(BaseModel):
